/*
 Tecnisa - Tecnologia em Informtica

 Nome: CONSULTA_REGRA_FISCAL

  Descrio:
  Funo para detectar a regra fiscal a ser considerada e, posteriormente, preencher as tabelas temporrias de alquota,
  incidncia, cfop e cst conforme a regra encontrada.

 Criao:
 11/06/2012 - Marcelo Alexsandro Souza Silva
*/

IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'CONSULTA_REGRA_FISCAL'
             AND TYPE = 'TF'
             AND U.UID = O.UID
             AND U.NAME = USER)
DROP FUNCTION CONSULTA_REGRA_FISCAL
GO

CREATE FUNCTION CONSULTA_REGRA_FISCAL
(
@P_CDIMPOSTO   VARCHAR(2),
@P_EMPRESA     VARCHAR(2),
@P_CDGRUPOFISC VARCHAR(3),
@P_ENTRSAIDIN  VARCHAR(1),
@P_TIPOOPER    VARCHAR(2),
@P_INSCESTA    VARCHAR(16),
@P_CDARVPROD   VARCHAR(20),
@P_DTENTRSAID  DATETIME,
@P_PAISORIG    VARCHAR(4),
@P_ESTAORIG    VARCHAR(2),
@P_MUNIORIG    VARCHAR(4),
@P_PAISDEST    VARCHAR(4),
@P_ESTADEST    VARCHAR(2),
@P_MUNIDEST    VARCHAR(4),
@P_BASECALC    DOUBLE PRECISION,
@P_CFOP        VARCHAR(1),
@P_IDORIGEMPROD VARCHAR(1) = 'N'
)
returns @REGRAFISCAL_TABLE table
  (
CDREGRAFISC      VARCHAR(10),
NMREGRAFISC      VARCHAR(50),
NRSEQDADOSFISC   VARCHAR(10),
CDCLASFISC       VARCHAR(10),
CDPRODUTO        VARCHAR(10),
DSMENSREGRAFISC  VARCHAR(150),
CDIMPOSTO        VARCHAR(2),
CDFISCAL         VARCHAR(1),
CDSITUTRIB       VARCHAR(2),
VRALIQUOTA       DOUBLE PRECISION,
IDMODBCNFE       VARCHAR(1),
IDMODBCSTNFE     VARCHAR(1),
IDMOTIDESSTNFE   VARCHAR(2),
CDTPCRPICOSTNFE  VARCHAR(3),
CDNATUBCPCSTNFE  VARCHAR(2),
VRINIFAIXA       DOUBLE PRECISION,
VRFIMFAIXA       DOUBLE PRECISION,
VRPARDEDUZ       DOUBLE PRECISION,
VR1PERREDBC      DOUBLE PRECISION,
VRPERREDBC       DOUBLE PRECISION,
VRPBCSUBTRIB     DOUBLE PRECISION,
IDTRATIMPST      VARCHAR(1),
IDPMCBASECA      VARCHAR(1),
IDCSTINTEREST    VARCHAR(1),
IDCSTINTERNA     VARCHAR(1),
CDFISCOPER       VARCHAR(10),
IDCFOPINTEREST   VARCHAR(1),
IDDIFEALIQ       VARCHAR(1),
IDDIFALIQCUSPR   VARCHAR(1),
IDTIPODESTFISC   VARCHAR(1),
CDDETALHEFISC    VARCHAR(5),
IDTIPOREGISTRO   VARCHAR(4),
IDMENSAGEM       VARCHAR(1),
CDENQLEGALIPI    VARCHAR(3),
CDCEST           VARCHAR(9),
VRADICALIQFECP   DOUBLE PRECISION
)
AS
BEGIN

   DECLARE @V_PCDFISCOPER          VARCHAR(10);
   DECLARE @V_PIDCFOPINTEREST      VARCHAR(1);
   DECLARE @V_PIDDIFEALIQ          VARCHAR(1);
   DECLARE @V_PIDDIFALIQCUSPR      VARCHAR(1);
   DECLARE @V_PIDTIPOREGISTRO      VARCHAR(4);
   DECLARE @V_PCDPRODUTO           VARCHAR(10);
   DECLARE @V_PCDCLASFISC          VARCHAR(10);
   DECLARE @V_PIDMENSAGEM          VARCHAR(01);

   DECLARE @V_CDREGRAFISC         VARCHAR(10);
   DECLARE @V_NMREGRAFISC         VARCHAR(50);
   DECLARE @V_DSMENSREGRAFISC     VARCHAR(150);
   DECLARE @V_CDFISCOPER          VARCHAR(10);
   DECLARE @V_IDCFOPINTEREST      VARCHAR(1);
   DECLARE @V_IDDIFEALIQ          VARCHAR(1);
   DECLARE @V_IDDIFALIQCUSPR      VARCHAR(1);
   DECLARE @V_UTFAIXVLR           VARCHAR(1);
   DECLARE @V_UTMUNIORIG          VARCHAR(1);
   DECLARE @V_UTUFORIG            VARCHAR(1);
   DECLARE @V_UTUFDEST            VARCHAR(1);
   DECLARE @V_CDFISCAL            VARCHAR(1);
   DECLARE @V_CDSITUTRIB          VARCHAR(2);
   DECLARE @V_VRALIQUOTA          DOUBLE PRECISION;
   DECLARE @V_IDMODBCNFE          VARCHAR(1);
   DECLARE @V_IDMODBCSTNFE        VARCHAR(1);
   DECLARE @V_IDMOTIDESSTNFE      VARCHAR(2);
   DECLARE @V_CDTPCRPICOSTNFE     VARCHAR(3);
   DECLARE @V_CDNATUBCPCSTNFE     VARCHAR(2);
   DECLARE @V_VRINIFAIXA          DOUBLE PRECISION;
   DECLARE @V_VRFIMFAIXA          DOUBLE PRECISION;
   DECLARE @V_VRPARDEDUZ          DOUBLE PRECISION;
   DECLARE @V_VR1PERREDBC         DOUBLE PRECISION;
   DECLARE @V_VRPERREDBC          DOUBLE PRECISION;
   DECLARE @V_VRPBCSUBTRIB        DOUBLE PRECISION;
   DECLARE @V_IDTRATIMPST         VARCHAR(1);
   DECLARE @V_IDPMCBASECA         VARCHAR(1);
   DECLARE @V_IDCSTINTEREST       VARCHAR(1);
   DECLARE @V_IDCSTINTERNA        VARCHAR(1);
   DECLARE @V_IDTIPODESTFISC      VARCHAR(1);
   DECLARE @V_CDDETALHEFISC       VARCHAR(5);
   DECLARE @V_STATUSESTADUAL      VARCHAR(1);
   DECLARE @V_STATUSINTERNACIONAL VARCHAR(1);
   DECLARE @V_IDTIPOREGISTRO      VARCHAR(4);
   DECLARE @V_NRSEQDADOSFISC      VARCHAR(10);
   DECLARE @V_IDMENSAGEM          VARCHAR(01);
   DECLARE @V_CDCLASFISC          VARCHAR(10);
   DECLARE @V_CDPRODUTO           VARCHAR(10);
   DECLARE @V_VRQTDEMB            DOUBLE PRECISION;
   DECLARE @V_SGUNIDEMB           VARCHAR(05);
   DECLARE @V_UTILRANGE           VARCHAR(01);
   DECLARE @V_IDORIGEMPROD        VARCHAR(01);
   DECLARE @V_CDIMPOSTONFE        VARCHAR(02);
   DECLARE @V_CDENQLEGALIPI       VARCHAR(03);
   DECLARE @V_CDCEST              VARCHAR(09);
   DECLARE @V_IDUTORIGPROD        VARCHAR(01);
   DECLARE @V_VRADICALIQFECP      DOUBLE PRECISION;

   DECLARE @V_REGRAFISCAL_CDIMPOSTO VARCHAR(02);
   DECLARE @V_REGRAFISCAL_ORDEM     VARCHAR(20);

   DECLARE C_REGRAFISCAL CURSOR FOR
      SELECT V.CDIMPOSTO, MIN(CONVERT(VARCHAR, V.NRORDPRIORIDADE)+'_'+R.CDREGRAFISC) ORDEM
         FROM REGRAFISCAL R,
          (
           SELECT MAX(CONVERT(VARCHAR, REGAUX.DTVALREGRAFISC, 112)+'_'+REGAUX.CDREGRAFISC) NUMERO, NRORDPRIORIDADE, CDIMPOSTO
             FROM VINCULOFISREGRA, IMPREGRAFISCAL I, REGRAFISCAL REGAUX
            WHERE VINCULOFISREGRA.CDEMPRESA = @P_EMPRESA
              AND VINCULOFISREGRA.CDREGRAFISC = REGAUX.CDREGRAFISC
              AND REGAUX.IDATIVREGRAFISC = 'S'
              AND ((REGAUX.DTVALREGRAFISC <= CONVERT(DATETIME, @P_DTENTRSAID, 103)) OR (REGAUX.DTVALREGRAFISC IS NULL) OR (@P_DTENTRSAID IS NULL))
              AND (VINCULOFISREGRA.IDENTRSAIDOP = @P_ENTRSAIDIN  OR IDENTRSAIDOP IS NULL)
              AND (VINCULOFISREGRA.CDTIPOOPER = @P_TIPOOPER      OR CDTIPOOPER IS NULL)
              AND (VINCULOFISREGRA.CDINSCESTA = @P_INSCESTA      OR CDINSCESTA IS NULL)
              AND (I.CDIMPOSTO                = @P_CDIMPOSTO     OR @P_CDIMPOSTO IS NULL)
              AND (I.CDREGRAFISC = REGAUX.CDREGRAFISC)
              AND (I.IDIMPOBRIGREGRA = 'S')
              AND ((VINCULOFISREGRA.DTVALVINCFISC >= CONVERT(DATETIME, @P_DTENTRSAID, 103)) OR (VINCULOFISREGRA.DTVALVINCFISC IS NULL) OR (@P_DTENTRSAID IS NULL))
              AND ((@P_CDGRUPOFISC IS NULL     AND NOT EXISTS (SELECT 1 FROM GRUPOFISCREGRA  WHERE GRUPOFISCREGRA.CDREGRAFISC = REGAUX.CDREGRAFISC)) OR
                   (@P_CDGRUPOFISC IS NOT NULL AND     EXISTS (SELECT 1 FROM GRUPOFISCREGRA WHERE GRUPOFISCREGRA.CDREGRAFISC = REGAUX.CDREGRAFISC AND GRUPOFISCREGRA.CDGRUPOFISC = @P_CDGRUPOFISC)))
           GROUP BY NRORDPRIORIDADE, CDIMPOSTO) V
       WHERE R.CDREGRAFISC = SUBSTRING(V.NUMERO, (CHARINDEX('_', V.NUMERO)) + 1, 10)
       GROUP BY V.CDIMPOSTO
       ORDER BY V.CDIMPOSTO;
   OPEN C_REGRAFISCAL;
   FETCH NEXT FROM C_REGRAFISCAL INTO @V_REGRAFISCAL_CDIMPOSTO, @V_REGRAFISCAL_ORDEM;
   WHILE (@@FETCH_STATUS = 0)
   BEGIN
      SET @V_UTFAIXVLR  = 'N';
      SET @V_UTMUNIORIG = 'N';
      SET @V_UTUFORIG   = 'N';
      SET @V_UTUFDEST   = 'N';
      SELECT @V_UTFAIXVLR = MAX(IDUTFAIXVLR), @V_UTMUNIORIG = MAX(IDUTMUNIORIG), @V_UTUFORIG = MAX(IDUTUFORIG),
             @V_UTUFDEST = MAX(IDUTUFDEST),   @V_CDIMPOSTONFE = MAX(CDIMPOSTONFE)
        FROM IMPOSTO
       WHERE IMPOSTO.CDIMPOSTO = @V_REGRAFISCAL_CDIMPOSTO;

      SET @V_PCDFISCOPER     = NULL;
      SET @V_PIDCFOPINTEREST = NULL;
      SET @V_PIDDIFEALIQ     = NULL;
      SET @V_PIDDIFALIQCUSPR = NULL;
      SET @V_PIDTIPOREGISTRO = NULL;
      SET @V_PIDMENSAGEM     = NULL;
      SET @V_PCDCLASFISC     = NULL;
      SET @V_PCDPRODUTO      = NULL;

      SET @V_CDFISCOPER     = NULL;
      SET @V_IDCFOPINTEREST = NULL;
      SET @V_IDDIFEALIQ     = NULL;
      SET @V_IDDIFALIQCUSPR = NULL;
      SET @V_IDTIPOREGISTRO = NULL;
      SET @V_IDMENSAGEM     = NULL;
      SET @V_CDCLASFISC     = NULL;
      SET @V_CDPRODUTO      = NULL;
      SET @V_IDORIGEMPROD   = NULL;
      SET @V_CDENQLEGALIPI  = NULL;
      SET @V_CDCEST         = NULL;
      SET @V_IDUTORIGPROD   = NULL;
      SET @V_VRADICALIQFECP = NULL;

      IF (@V_CDIMPOSTONFE = '00') BEGIN
         SELECT @V_IDUTORIGPROD = ISNULL(IDUTORIGPROD, 'N')
           FROM PARAMGERAL
          WHERE CDPARGERAL = '0001';
         IF @V_IDUTORIGPROD = 'S' BEGIN
            SET @V_IDORIGEMPROD = @P_IDORIGEMPROD;
         END 
         ELSE BEGIN
            SET @V_IDORIGEMPROD = 'N';
         END;
      END
      ELSE BEGIN
         SET @V_IDORIGEMPROD = 'N';
      END;

      SET @V_CDREGRAFISC = SUBSTRING(@V_REGRAFISCAL_ORDEM, (CHARINDEX('_', @V_REGRAFISCAL_ORDEM)) + 1, 10);
      IF (@P_PAISORIG+@P_ESTAORIG) <> (@P_PAISDEST+@P_ESTADEST) BEGIN
         SELECT @V_PCDFISCOPER = MAX(CDFISCOPER),
                @V_PIDCFOPINTEREST = MAX(IDCFOPINTEREST),
                @V_PIDDIFEALIQ = MAX(IDDIFEALIQ),
                @V_PIDDIFALIQCUSPR = MAX(IDDIFALIQCUSPR),
                @V_PIDTIPOREGISTRO = CONVERT(VARCHAR, MAX('PROD')),
                @V_PCDPRODUTO = MAX(CFOPREGRAFISCAL.CDPRODUTO)
           FROM CFOPREGRAFISCAL, PRODUTO PRODUTOREGRA
          WHERE CFOPREGRAFISCAL.CDREGRAFISC = @V_CDREGRAFISC
            AND PRODUTOREGRA.CDPRODUTO = CFOPREGRAFISCAL.CDPRODUTO
            AND ((IDCFOPINTEREST = 'I') OR (IDCFOPINTEREST = 'T'))
            AND PRODUTOREGRA.CDARVPROD = (SELECT MAX(B.CDARVPROD)
                                            FROM CFOPREGRAFISCAL A, PRODUTO B
                                           WHERE A.CDREGRAFISC = @V_CDREGRAFISC
                                             AND A.CDPRODUTO = B.CDPRODUTO
                                             AND CHARINDEX(B.CDARVPROD, @P_CDARVPROD) = 1);

         SELECT @V_PIDMENSAGEM = (CASE COUNT(MSGCFOPREGFISC.CDREGRAFISC) WHEN  0 THEN 'N' ELSE 'S' END)
           FROM MSGCFOPREGFISC
          WHERE CDREGRAFISC = @V_CDREGRAFISC
            AND IDCFOPINTEREST = @V_PIDCFOPINTEREST
            AND CDPRODUTO = @V_PCDPRODUTO;

         IF @V_PCDFISCOPER IS NULL BEGIN
            SELECT
               @V_PCDFISCOPER = MAX(CDFISCOPER),
               @V_PIDCFOPINTEREST = MAX(IDCFOPINTEREST),
               @V_PIDDIFEALIQ = MAX(IDDIFEALIQ),
               @V_PIDDIFALIQCUSPR = MAX(IDDIFALIQCUSPR),
               @V_PIDTIPOREGISTRO = CONVERT(VARCHAR, MAX('NCM')),
               @V_PCDCLASFISC = MAX(CDCLASFISC)
              FROM CFOPNCMREGRAFIS
             WHERE CFOPNCMREGRAFIS.CDREGRAFISC = @V_CDREGRAFISC
               AND ((IDCFOPINTEREST = 'I') OR (IDCFOPINTEREST = 'T'))
               AND CFOPNCMREGRAFIS.CDCLASFISC = (SELECT MAX(A.CDCLASFISC)
                                                      FROM CFOPNCMREGRAFIS A, PRODUTO B
                                                     WHERE A.CDREGRAFISC = @V_CDREGRAFISC
                                                       AND B.CDARVPROD = @P_CDARVPROD
                                                       AND CHARINDEX(A.CDCLASFISC, B.CDCLASFISC)=1);

            SELECT @V_PIDMENSAGEM = (CASE COUNT(MSGCFOPNCM.CDREGRAFISC) WHEN 0 THEN 'N' ELSE 'S' END)
              FROM MSGCFOPNCM
             WHERE CDREGRAFISC = @V_CDREGRAFISC
               AND CDCLASFISC = @V_PCDCLASFISC
               AND IDCFOPINTEREST = @V_PIDCFOPINTEREST;

            IF @V_PCDFISCOPER IS NULL BEGIN
               SELECT @V_PCDFISCOPER = MAX(CDFISCOPER),
                      @V_PIDCFOPINTEREST = MAX(IDCFOPINTEREST),
                      @V_PIDDIFEALIQ = MAX(IDDIFEALIQ),
                      @V_PIDDIFALIQCUSPR = MAX(IDDIFALIQCUSPR),
                      @V_PIDTIPOREGISTRO = CONVERT(VARCHAR, MAX('PAD'))
                 FROM CFOPADRAOREGFIS
                WHERE CFOPADRAOREGFIS.CDREGRAFISC = @V_CDREGRAFISC
                  AND ((IDCFOPINTEREST = 'I') OR (IDCFOPINTEREST = 'T'));

               SELECT @V_PIDMENSAGEM = (CASE COUNT(MSGCFOPADRAO.CDREGRAFISC) WHEN 0 THEN 'N' ELSE 'S' END)
                 FROM MSGCFOPADRAO
                WHERE CDREGRAFISC = @V_CDREGRAFISC
                  AND IDCFOPINTEREST = @V_PIDCFOPINTEREST;
            END;
         END;
      END
      ELSE BEGIN
         SELECT @V_PCDFISCOPER = MAX(CDFISCOPER),
                @V_PIDCFOPINTEREST = MAX(IDCFOPINTEREST),
                @V_PIDDIFEALIQ = MAX(IDDIFEALIQ),
                @V_PIDDIFALIQCUSPR = MAX(IDDIFALIQCUSPR),
                @V_PIDTIPOREGISTRO = CONVERT(VARCHAR, MAX('PROD')),
                @V_PCDPRODUTO = MAX(CFOPREGRAFISCAL.CDPRODUTO)
           FROM CFOPREGRAFISCAL, PRODUTO PRODUTOREGRA
          WHERE CFOPREGRAFISCAL.CDREGRAFISC = @V_CDREGRAFISC
            AND PRODUTOREGRA.CDPRODUTO = CFOPREGRAFISCAL.CDPRODUTO
            AND ((IDCFOPINTEREST = 'E') OR (IDCFOPINTEREST = 'T'))
            AND PRODUTOREGRA.CDARVPROD = (SELECT MAX(B.CDARVPROD)
                                            FROM CFOPREGRAFISCAL A, PRODUTO B
                                           WHERE A.CDREGRAFISC = @V_CDREGRAFISC
                                             AND A.CDPRODUTO = B.CDPRODUTO
                                             AND CHARINDEX(B.CDARVPROD, @P_CDARVPROD) = 1);
         SELECT @V_PIDMENSAGEM = (CASE COUNT(MSGCFOPREGFISC.CDREGRAFISC) WHEN 0 THEN 'N' ELSE 'S' END)
           FROM MSGCFOPREGFISC
          WHERE CDREGRAFISC = @V_CDREGRAFISC
            AND IDCFOPINTEREST = @V_PIDCFOPINTEREST
            AND CDPRODUTO = @V_PCDPRODUTO;

         IF @V_PCDFISCOPER IS NULL BEGIN
            SELECT
               @V_PCDFISCOPER = MAX(CDFISCOPER),
               @V_PIDCFOPINTEREST = MAX(IDCFOPINTEREST),
               @V_PIDDIFEALIQ = MAX(IDDIFEALIQ),
               @V_PIDDIFALIQCUSPR = MAX(IDDIFALIQCUSPR),
               @V_PIDTIPOREGISTRO = CONVERT(VARCHAR, MAX('NCM')),
               @V_PCDCLASFISC = MAX(CDCLASFISC)
              FROM CFOPNCMREGRAFIS
             WHERE CFOPNCMREGRAFIS.CDREGRAFISC = @V_CDREGRAFISC
               AND ((IDCFOPINTEREST = 'E') OR (IDCFOPINTEREST = 'T'))
               AND CFOPNCMREGRAFIS.CDCLASFISC = (SELECT MAX(A.CDCLASFISC)
                                                      FROM CFOPNCMREGRAFIS A, PRODUTO B
                                                     WHERE A.CDREGRAFISC = @V_CDREGRAFISC
                                                       AND B.CDARVPROD = @P_CDARVPROD
                                                       AND CHARINDEX(B.CDCLASFISC, A.CDCLASFISC)=1);
            SELECT @V_PIDMENSAGEM = (CASE COUNT(MSGCFOPNCM.CDREGRAFISC) WHEN 0 THEN 'N' ELSE 'S' END)
              FROM MSGCFOPNCM
             WHERE CDREGRAFISC = @V_CDREGRAFISC
               AND CDCLASFISC = @V_PCDCLASFISC
               AND IDCFOPINTEREST = @V_PIDCFOPINTEREST;

            IF @V_PCDFISCOPER IS NULL BEGIN
               SELECT @V_PCDFISCOPER = MAX(CDFISCOPER),
                      @V_PIDCFOPINTEREST = MAX(IDCFOPINTEREST),
                      @V_PIDDIFEALIQ = MAX(IDDIFEALIQ),
                      @V_PIDDIFALIQCUSPR = MAX(IDDIFALIQCUSPR),
                      @V_PIDTIPOREGISTRO = CONVERT(VARCHAR, MAX('PAD'))
                 FROM CFOPADRAOREGFIS
                WHERE CFOPADRAOREGFIS.CDREGRAFISC = @V_CDREGRAFISC
                  AND ((IDCFOPINTEREST = 'E') OR (IDCFOPINTEREST = 'T'));

               SELECT @V_PIDMENSAGEM = (CASE COUNT(MSGCFOPADRAO.CDREGRAFISC) WHEN 0 THEN 'N' ELSE 'S' END)
                 FROM MSGCFOPADRAO
                WHERE CDREGRAFISC = @V_CDREGRAFISC
                  AND IDCFOPINTEREST = @V_PIDCFOPINTEREST;
            END;
         END;
      END;

      SET @V_CDFISCAL        = NULL;
      SET @V_CDSITUTRIB      = NULL;
      SET @V_VRALIQUOTA      = NULL;
      SET @V_IDMODBCNFE      = NULL;
      SET @V_IDMODBCSTNFE    = NULL;
      SET @V_IDMOTIDESSTNFE  = NULL;
      SET @V_CDTPCRPICOSTNFE = NULL;
      SET @V_CDNATUBCPCSTNFE = NULL;
      SET @V_VRINIFAIXA      = NULL;
      SET @V_VRFIMFAIXA      = NULL;
      SET @V_VRPARDEDUZ      = NULL;
      SET @V_VR1PERREDBC     = NULL;
      SET @V_VRPERREDBC      = NULL;
      SET @V_VRPBCSUBTRIB    = NULL;
      SET @V_IDTRATIMPST     = NULL;
      SET @V_IDPMCBASECA     = NULL;
      SET @V_IDCSTINTEREST   = NULL;
      SET @V_IDCSTINTERNA    = NULL;
      SET @V_IDTIPODESTFISC  = NULL;
      SET @V_CDDETALHEFISC   = NULL;
      SET @V_CDENQLEGALIPI   = NULL;
      SET @V_CDCEST          = NULL;
      SET @V_VRADICALIQFECP  = NULL;

      IF @P_CFOP = 'N' BEGIN
         IF (@P_PAISORIG+@P_ESTAORIG) <> (@P_PAISDEST+@P_ESTADEST) BEGIN
            SET @V_STATUSESTADUAL = 'I';
         END
         ELSE BEGIN
            SET @V_STATUSESTADUAL = 'E';
         END;
         IF (@P_PAISORIG) <> (@P_PAISDEST) BEGIN
            SET @V_STATUSINTERNACIONAL = 'I';
         END
         ELSE BEGIN
            SET @V_STATUSINTERNACIONAL = 'N';
         END;
         SELECT
            @V_CDFISCAL         = MAX(CDFISCAL),
            @V_CDSITUTRIB       = MAX(CDSITUTRIB),
            @V_VRALIQUOTA       = MAX(VRALIQUOTA),
            @V_IDMODBCNFE       = MAX(IDMODBCNFE),
            @V_IDMODBCSTNFE     = MAX(IDMODBCSTNFE),
            @V_IDMOTIDESSTNFE   = MAX(IDMOTIDESSTNFE),
            @V_CDTPCRPICOSTNFE  = MAX(CDTPCRPICOSTNFE),
            @V_CDNATUBCPCSTNFE  = MAX(CDNATUBCPCSTNFE),
            @V_VRINIFAIXA       = MAX(VRINIFAIXA),
            @V_VRFIMFAIXA       = MAX(VRFIMFAIXA),
            @V_VRPARDEDUZ       = MAX(VRPARDEDUZ),
            @V_VR1PERREDBC      = MAX(VR1PERREDBC),
            @V_VRPERREDBC       = MAX(VRPERREDBC),
            @V_VRPBCSUBTRIB     = MAX(VRPBCSUBTRIB),
            @V_IDTRATIMPST      = MAX(IDTRATIMPST),
            @V_IDPMCBASECA      = MAX(IDPMCBASECA),
            @V_IDCSTINTEREST    = MAX(IDCSTINTEREST),
            @V_IDCSTINTERNA     = MAX(IDCSTINTERNA),
            @V_IDTIPODESTFISC   = MAX(IDTIPODESTFISC),
            @V_CDDETALHEFISC    = MAX(CDDETALHEFISC),
            @V_IDTIPOREGISTRO   = CONVERT(VARCHAR, MAX('PROD')),
            @V_NRSEQDADOSFISC   = MAX(NRSEQDADOSFISC),
            @V_CDCLASFISC       = '',
            @V_CDPRODUTO        = MAX(DADOSFISCPROD.CDPRODUTO),
            @V_CDFISCOPER       = MAX(CDFISCOPER),
            @V_IDDIFEALIQ       = MAX(IDDIFEALIQ),
            @V_IDDIFALIQCUSPR   = MAX(IDDIFALIQCUSPR),
            @V_CDENQLEGALIPI    = MAX(CDENQLEGALIPI),
            @V_CDCEST           = MAX(DADOSFISCPROD.CDCEST),
            @V_VRADICALIQFECP   = MAX(DADOSFISCPROD.VRADICALIQFECP)
           FROM DADOSFISCPROD, PRODUTO PRODUTOREGRA
          WHERE DADOSFISCPROD.CDREGRAFISC = @V_CDREGRAFISC
            AND DADOSFISCPROD.CDIMPOSTO = @V_REGRAFISCAL_CDIMPOSTO
            AND PRODUTOREGRA.CDPRODUTO = DADOSFISCPROD.CDPRODUTO
            AND (IDCSTINTEREST = @V_STATUSESTADUAL OR IDCSTINTEREST = 'T')
            AND (IDCSTINTERNA  = @V_STATUSINTERNACIONAL OR IDCSTINTERNA = 'T')
            AND (((CDPAISORIG = @P_PAISORIG) AND (SGESTAORIG = @P_ESTAORIG)) OR  @V_UTUFORIG = 'N' OR IDTIPOORIGFISC = 'T')
            AND (((CDPAISDEST = @P_PAISDEST) AND (SGESTADEST = @P_ESTADEST)) OR  @V_UTUFDEST = 'N' OR IDTIPODESTFISC = 'T')
            AND (((CDMUNIORIG = @P_MUNIORIG  AND @V_UTMUNIORIG = 'O') OR (IDTIPOORIGFISC = 'T') OR ((CDMUNIORIG IS NULL) AND  (@V_UTMUNIORIG = 'D'))) AND
                 ((CDMUNIDEST = @P_MUNIDEST AND @V_UTMUNIORIG = 'D') OR (IDTIPODESTFISC = 'T') OR ((CDMUNIDEST IS NULL) AND  (@V_UTMUNIORIG = 'O'))) OR
                 (@V_UTMUNIORIG = 'N'))
            AND ((VRINIFAIXA <= @P_BASECALC)  AND (VRFIMFAIXA  >= @P_BASECALC) OR  @V_UTFAIXVLR = 'N')
            AND (ISNULL(IDORIGEMPRODIMP, 'N') =  ISNULL(@V_IDORIGEMPROD, 'N'))
            AND PRODUTOREGRA.CDARVPROD = (SELECT MAX(B.CDARVPROD)
                                            FROM DADOSFISCPROD A, PRODUTO B
                                           WHERE A.CDREGRAFISC = @V_CDREGRAFISC
                                             AND A.CDPRODUTO = B.CDPRODUTO
                                             AND A.CDIMPOSTO = @V_REGRAFISCAL_CDIMPOSTO
                                             AND CHARINDEX(B.CDARVPROD, @P_CDARVPROD) = 1
                                             AND (IDCSTINTEREST = @V_STATUSESTADUAL OR IDCSTINTEREST = 'T')
                                             AND (IDCSTINTERNA  = @V_STATUSINTERNACIONAL OR IDCSTINTERNA = 'T')
                                             AND (((CDPAISORIG = @P_PAISORIG) AND (SGESTAORIG = @P_ESTAORIG)) OR  @V_UTUFORIG = 'N' OR IDTIPOORIGFISC = 'T')
                                             AND (((CDPAISDEST = @P_PAISDEST) AND (SGESTADEST = @P_ESTADEST)) OR  @V_UTUFDEST = 'N' OR IDTIPODESTFISC = 'T')
                                             AND (((CDMUNIORIG = @P_MUNIORIG  AND @V_UTMUNIORIG = 'O') OR (IDTIPOORIGFISC = 'T') OR ((CDMUNIORIG IS NULL) AND  (@V_UTMUNIORIG = 'D'))) AND
                                                  ((CDMUNIDEST = @P_MUNIDEST AND @V_UTMUNIORIG = 'D') OR (IDTIPODESTFISC = 'T') OR ((CDMUNIDEST IS NULL) AND  (@V_UTMUNIORIG = 'O'))) OR
                                                  (@V_UTMUNIORIG = 'N')));
         SELECT @V_IDMENSAGEM = (CASE COUNT(MSGFISCPROD.CDREGRAFISC) WHEN 0 THEN 'N' ELSE 'S' END)
           FROM MSGFISCPROD
          WHERE CDREGRAFISC    = @V_CDREGRAFISC
            AND CDIMPOSTO      = @V_REGRAFISCAL_CDIMPOSTO
            AND NRSEQDADOSFISC = @V_NRSEQDADOSFISC
            AND CDPRODUTO      = @V_CDPRODUTO;
         IF @V_CDFISCAL IS NULL BEGIN
            SELECT @V_VRQTDEMB  = MAX(VRQTDEMB),
                   @V_SGUNIDEMB = MAX(SGUNIDEMB)
              FROM PRODUTO
             WHERE CDARVPROD = @P_CDARVPROD;

            SELECT
               @V_CDFISCAL         = MAX(CDFISCAL),
               @V_CDSITUTRIB       = MAX(CDSITUTRIB),
               @V_VRALIQUOTA       = MAX(VRALIQUOTA),
               @V_IDMODBCNFE       = MAX(IDMODBCNFE),
               @V_IDMODBCSTNFE     = MAX(IDMODBCSTNFE),
               @V_IDMOTIDESSTNFE   = MAX(IDMOTIDESSTNFE),
               @V_CDTPCRPICOSTNFE  = MAX(CDTPCRPICOSTNFE),
               @V_CDNATUBCPCSTNFE  = MAX(CDNATUBCPCSTNFE),
               @V_VRINIFAIXA       = MAX(VRINIFAIXA),
               @V_VRFIMFAIXA       = MAX(VRFIMFAIXA),
               @V_VRPARDEDUZ       = MAX(VRPARDEDUZ),
               @V_VR1PERREDBC      = MAX(VR1PERREDBC),
               @V_VRPERREDBC       = MAX(VRPERREDBC),
               @V_VRPBCSUBTRIB     = MAX(VRPBCSUBTRIB),
               @V_IDTRATIMPST      = MAX(IDTRATIMPST),
               @V_IDPMCBASECA      = MAX(IDPMCBASECA),
               @V_IDCSTINTEREST    = MAX(IDCSTINTEREST),
               @V_IDCSTINTERNA     = MAX(IDCSTINTERNA),
               @V_IDTIPODESTFISC   = MAX(IDTIPODESTFISC),
               @V_CDDETALHEFISC    = MAX(CDDETALHEFISC),
               @V_IDTIPOREGISTRO   = CONVERT(VARCHAR, MAX('NCM')),
               @V_NRSEQDADOSFISC   = MAX(NRSEQDADOSFISC),
               @V_CDCLASFISC       = MAX(CDCLASFISC),
               @V_CDPRODUTO        = '',
               @V_CDFISCOPER       = MAX(CDFISCOPER),
               @V_IDDIFEALIQ       = MAX(IDDIFEALIQ),
               @V_IDDIFALIQCUSPR   = MAX(IDDIFALIQCUSPR),
               @V_CDENQLEGALIPI    = MAX(CDENQLEGALIPI),
               @V_CDCEST           = MAX(CDCEST),
               @V_VRADICALIQFECP   = MAX(VRADICALIQFECP)
              FROM DADOSFISCNCM
             WHERE DADOSFISCNCM.CDREGRAFISC = @V_CDREGRAFISC
               AND DADOSFISCNCM.CDIMPOSTO = @V_REGRAFISCAL_CDIMPOSTO
               AND (IDCSTINTEREST = @V_STATUSESTADUAL OR IDCSTINTEREST = 'T')
               AND (IDCSTINTERNA  = @V_STATUSINTERNACIONAL OR IDCSTINTERNA = 'T')
               AND (((CDPAISORIG = @P_PAISORIG) AND (SGESTAORIG = @P_ESTAORIG)) OR  @V_UTUFORIG = 'N' OR IDTIPOORIGFISC = 'T')
               AND (((CDPAISDEST = @P_PAISDEST) AND (SGESTADEST = @P_ESTADEST)) OR  @V_UTUFDEST = 'N' OR IDTIPODESTFISC = 'T')
               AND (((CDMUNIORIG = @P_MUNIORIG  AND @V_UTMUNIORIG = 'O') OR (IDTIPOORIGFISC = 'T') OR ((CDMUNIORIG IS NULL) AND  (@V_UTMUNIORIG = 'D'))) AND
                    ((CDMUNIDEST = @P_MUNIDEST AND @V_UTMUNIORIG = 'D') OR (IDTIPODESTFISC = 'T') OR ((CDMUNIDEST IS NULL) AND  (@V_UTMUNIORIG = 'O'))) OR
                    (@V_UTMUNIORIG = 'N'))
               AND ((VRINIFAIXA <= @P_BASECALC)  AND (VRFIMFAIXA  >= @P_BASECALC) OR  @V_UTFAIXVLR = 'N')
               AND ((VRRANGINI  <= @V_VRQTDEMB)  AND (VRRANGFIM   >= @V_VRQTDEMB) AND  SGUNIDEMB = @V_SGUNIDEMB)
               AND (ISNULL(IDORIGEMPRODIMP, 'N') =  ISNULL(@V_IDORIGEMPROD, 'N'))
               AND DADOSFISCNCM.CDCLASFISC = (SELECT MAX(A.CDCLASFISC)
                                                FROM DADOSFISCNCM A, PRODUTO B
                                               WHERE A.CDREGRAFISC = @V_CDREGRAFISC
                                                 and b.cdarvprod = @P_CDARVPROD
                                                 AND A.CDIMPOSTO = @V_REGRAFISCAL_CDIMPOSTO
                                                 AND CHARINDEX( a.CDCLASFISC ,b.CDCLASFISC)=1
                                                 AND (IDCSTINTEREST = @V_STATUSESTADUAL OR IDCSTINTEREST = 'T')
                                                 AND (IDCSTINTERNA  = @V_STATUSINTERNACIONAL OR IDCSTINTERNA = 'T')
                                                 AND (((CDPAISORIG = @P_PAISORIG) AND (SGESTAORIG = @P_ESTAORIG)) OR  @V_UTUFORIG = 'N' OR IDTIPOORIGFISC = 'T')
                                                 AND (((CDPAISDEST = @P_PAISDEST) AND (SGESTADEST = @P_ESTADEST)) OR  @V_UTUFDEST = 'N' OR IDTIPODESTFISC = 'T')
                                                 AND (((CDMUNIORIG = @P_MUNIORIG  AND @V_UTMUNIORIG = 'O') OR (IDTIPOORIGFISC = 'T') OR ((CDMUNIORIG IS NULL) AND  (@V_UTMUNIORIG = 'D'))) AND
                                                      ((CDMUNIDEST = @P_MUNIDEST AND @V_UTMUNIORIG = 'D') OR (IDTIPODESTFISC = 'T') OR ((CDMUNIDEST IS NULL) AND  (@V_UTMUNIORIG = 'O'))) OR
                                                      (@V_UTMUNIORIG = 'N')));
            SELECT @V_IDMENSAGEM = (CASE COUNT(MSGFISCNCM.CDREGRAFISC) WHEN 0 THEN 'N' ELSE 'S' END)
              FROM MSGFISCNCM
             WHERE CDREGRAFISC = @V_CDREGRAFISC
               AND CDIMPOSTO = @V_REGRAFISCAL_CDIMPOSTO
               AND CDCLASFISC = @V_CDCLASFISC
               AND NRSEQDADOSFISC = @V_NRSEQDADOSFISC;

            IF @V_CDFISCAL IS NULL BEGIN
               SELECT
                  @V_CDFISCAL         = MAX(CDFISCAL),
                  @V_CDSITUTRIB       = MAX(CDSITUTRIB),
                  @V_VRALIQUOTA       = MAX(VRALIQUOTA),
                  @V_IDMODBCNFE       = MAX(IDMODBCNFE),
                  @V_IDMODBCSTNFE     = MAX(IDMODBCSTNFE),
                  @V_IDMOTIDESSTNFE   = MAX(IDMOTIDESSTNFE),
                  @V_CDTPCRPICOSTNFE  = MAX(CDTPCRPICOSTNFE),
                  @V_CDNATUBCPCSTNFE  = MAX(CDNATUBCPCSTNFE),
                  @V_VRINIFAIXA       = MAX(VRINIFAIXA),
                  @V_VRFIMFAIXA       = MAX(VRFIMFAIXA),
                  @V_VRPARDEDUZ       = MAX(VRPARDEDUZ),
                  @V_VR1PERREDBC      = MAX(VR1PERREDBC),
                  @V_VRPERREDBC       = MAX(VRPERREDBC),
                  @V_VRPBCSUBTRIB     = MAX(VRPBCSUBTRIB),
                  @V_IDTRATIMPST      = MAX(IDTRATIMPST),
                  @V_IDPMCBASECA      = MAX(IDPMCBASECA),
                  @V_IDCSTINTEREST    = MAX(IDCSTINTEREST),
                  @V_IDCSTINTERNA     = MAX(IDCSTINTERNA),
                  @V_IDTIPODESTFISC   = MAX(IDTIPODESTFISC),
                  @V_CDDETALHEFISC    = MAX(CDDETALHEFISC),
                  @V_IDTIPOREGISTRO   = CONVERT(VARCHAR, MAX('NCM')),
                  @V_NRSEQDADOSFISC   = MAX(NRSEQDADOSFISC),
                  @V_CDCLASFISC       = MAX(CDCLASFISC),
                  @V_CDPRODUTO        = '',
                  @V_CDFISCOPER       = MAX(CDFISCOPER),
                  @V_IDDIFEALIQ       = MAX(IDDIFEALIQ),
                  @V_IDDIFALIQCUSPR   = MAX(IDDIFALIQCUSPR),
                  @V_CDENQLEGALIPI    = MAX(CDENQLEGALIPI),
                  @V_CDCEST           = MAX(CDCEST),
                  @V_VRADICALIQFECP   = MAX(VRADICALIQFECP)
                 FROM DADOSFISCNCM
                WHERE DADOSFISCNCM.CDREGRAFISC = @V_CDREGRAFISC
                  AND DADOSFISCNCM.CDIMPOSTO = @V_REGRAFISCAL_CDIMPOSTO
                  AND (IDCSTINTEREST = @V_STATUSESTADUAL OR IDCSTINTEREST = 'T')
                  AND (IDCSTINTERNA  = @V_STATUSINTERNACIONAL OR IDCSTINTERNA = 'T')
                  AND (((CDPAISORIG = @P_PAISORIG) AND (SGESTAORIG = @P_ESTAORIG)) OR  @V_UTUFORIG = 'N' OR IDTIPOORIGFISC = 'T')
                  AND (((CDPAISDEST = @P_PAISDEST) AND (SGESTADEST = @P_ESTADEST)) OR  @V_UTUFDEST = 'N' OR IDTIPODESTFISC = 'T')
                  AND (((CDMUNIORIG = @P_MUNIORIG  AND @V_UTMUNIORIG = 'O') OR (IDTIPOORIGFISC = 'T') OR ((CDMUNIORIG IS NULL) AND  (@V_UTMUNIORIG = 'D'))) AND
                       ((CDMUNIDEST = @P_MUNIDEST AND @V_UTMUNIORIG = 'D') OR (IDTIPODESTFISC = 'T') OR ((CDMUNIDEST IS NULL) AND  (@V_UTMUNIORIG = 'O'))) OR
                       (@V_UTMUNIORIG = 'N'))
                  AND ((VRINIFAIXA <= @P_BASECALC)  AND (VRFIMFAIXA  >= @P_BASECALC) OR  @V_UTFAIXVLR = 'N')
                  AND ((VRRANGINI IS NULL) AND (VRRANGFIM IS NULL))
                  AND (ISNULL(IDORIGEMPRODIMP, 'N') =  ISNULL(@V_IDORIGEMPROD, 'N'))
                  AND DADOSFISCNCM.CDCLASFISC = (SELECT MAX(A.CDCLASFISC)
                                                   FROM DADOSFISCNCM A, PRODUTO B
                                                  WHERE A.CDREGRAFISC = @V_CDREGRAFISC
                                                    and b.cdarvprod = @P_CDARVPROD
                                                    AND A.CDIMPOSTO = @V_REGRAFISCAL_CDIMPOSTO
                                                    AND CHARINDEX( a.CDCLASFISC ,b.CDCLASFISC)=1
                                                    AND (IDCSTINTEREST = @V_STATUSESTADUAL OR IDCSTINTEREST = 'T')
                                                    AND (IDCSTINTERNA  = @V_STATUSINTERNACIONAL OR IDCSTINTERNA = 'T')
                                                    AND (((CDPAISORIG = @P_PAISORIG) AND (SGESTAORIG = @P_ESTAORIG)) OR  @V_UTUFORIG = 'N' OR IDTIPOORIGFISC = 'T')
                                                    AND (((CDPAISDEST = @P_PAISDEST) AND (SGESTADEST = @P_ESTADEST)) OR  @V_UTUFDEST = 'N' OR IDTIPODESTFISC = 'T')
                                                    AND (((CDMUNIORIG = @P_MUNIORIG  AND @V_UTMUNIORIG = 'O') OR (IDTIPOORIGFISC = 'T') OR ((CDMUNIORIG IS NULL) AND  (@V_UTMUNIORIG = 'D'))) AND
                                                         ((CDMUNIDEST = @P_MUNIDEST AND @V_UTMUNIORIG = 'D') OR (IDTIPODESTFISC = 'T') OR ((CDMUNIDEST IS NULL) AND  (@V_UTMUNIORIG = 'O'))) OR
                                                         (@V_UTMUNIORIG = 'N')));
               SELECT @V_IDMENSAGEM = (CASE COUNT(MSGFISCNCM.CDREGRAFISC) WHEN 0 THEN 'N' ELSE 'S' END)
                 FROM MSGFISCNCM
                WHERE CDREGRAFISC = @V_CDREGRAFISC
                  AND CDIMPOSTO = @V_REGRAFISCAL_CDIMPOSTO
                  AND CDCLASFISC = @V_CDCLASFISC
                  AND NRSEQDADOSFISC = @V_NRSEQDADOSFISC;
            END;

            IF @V_CDFISCAL IS NULL BEGIN
               SELECT @V_VRQTDEMB  = MAX(VRQTDEMB),
                      @V_SGUNIDEMB = MAX(SGUNIDEMB)
                 FROM PRODUTO
                WHERE CDARVPROD = @P_CDARVPROD;

               SELECT @V_UTILRANGE = MAX(IDUTRANGEMB)
                 FROM IMPOSTO
                WHERE CDIMPOSTO = @V_REGRAFISCAL_CDIMPOSTO;

               SELECT
                  @V_CDFISCAL         = MAX(CDFISCAL),
                  @V_CDSITUTRIB       = MAX(CDSITUTRIB),
                  @V_VRALIQUOTA       = MAX(VRALIQUOTA),
                  @V_IDMODBCNFE       = MAX(IDMODBCNFE),
                  @V_IDMODBCSTNFE     = MAX(IDMODBCSTNFE),
                  @V_IDMOTIDESSTNFE   = MAX(IDMOTIDESSTNFE),
                  @V_CDTPCRPICOSTNFE  = MAX(CDTPCRPICOSTNFE),
                  @V_CDNATUBCPCSTNFE  = MAX(CDNATUBCPCSTNFE),
                  @V_VRINIFAIXA       = MAX(VRINIFAIXA),
                  @V_VRFIMFAIXA       = MAX(VRFIMFAIXA),
                  @V_VRPARDEDUZ       = MAX(VRPARDEDUZ),
                  @V_VR1PERREDBC      = MAX(VR1PERREDBC),
                  @V_VRPERREDBC       = MAX(VRPERREDBC),
                  @V_VRPBCSUBTRIB     = MAX(VRPBCSUBTRIB),
                  @V_IDTRATIMPST      = MAX(IDTRATIMPST),
                  @V_IDPMCBASECA      = MAX(IDPMCBASECA),
                  @V_IDCSTINTEREST    = MAX(IDCSTINTEREST),
                  @V_IDCSTINTERNA     = MAX(IDCSTINTERNA),
                  @V_IDTIPODESTFISC   = MAX(IDTIPODESTFISC),
                  @V_CDDETALHEFISC    = MAX(CDDETALHEFISC),
                  @V_IDTIPOREGISTRO   = CONVERT(VARCHAR, MAX('PAD')),
                  @V_NRSEQDADOSFISC   = MAX(NRSEQDADOSFISC),
                  @V_CDCLASFISC       =   '',
                  @V_CDPRODUTO        =   '',
                  @V_CDFISCOPER       = MAX(CDFISCOPER),
                  @V_IDDIFEALIQ       = MAX(IDDIFEALIQ),
                  @V_IDDIFALIQCUSPR   = MAX(IDDIFALIQCUSPR),
                  @V_CDENQLEGALIPI    = MAX(CDENQLEGALIPI),
                  @V_CDCEST           = MAX(CDCEST),
                  @V_VRADICALIQFECP   = MAX(VRADICALIQFECP)
                FROM DADOSFISCREGRA
               WHERE DADOSFISCREGRA.CDREGRAFISC = @V_CDREGRAFISC
                  AND DADOSFISCREGRA.CDIMPOSTO = @V_REGRAFISCAL_CDIMPOSTO
                  AND (IDCSTINTEREST = @V_STATUSESTADUAL OR IDCSTINTEREST = 'T')
                  AND (IDCSTINTERNA  = @V_STATUSINTERNACIONAL OR IDCSTINTERNA = 'T')
                  AND (((CDPAISORIG  = @P_PAISORIG) AND (SGESTAORIG   = @P_ESTAORIG)) OR @V_UTUFORIG = 'N' OR IDTIPOORIGFISC = 'T')
                  AND (((CDPAISDEST  = @P_PAISDEST) AND (SGESTADEST   = @P_ESTADEST)) OR @V_UTUFDEST = 'N' OR IDTIPODESTFISC = 'T')
                  AND (((CDMUNIORIG = @P_MUNIORIG  AND @V_UTMUNIORIG = 'O') OR (IDTIPOORIGFISC = 'T') OR ((CDMUNIORIG IS NULL) AND  (@V_UTMUNIORIG = 'D'))) AND
                       ((CDMUNIDEST = @P_MUNIDEST AND @V_UTMUNIORIG = 'D') OR (IDTIPODESTFISC = 'T') OR ((CDMUNIDEST IS NULL) AND  (@V_UTMUNIORIG = 'O'))) OR
                       (@V_UTMUNIORIG = 'N'))
                  AND ((VRINIFAIXA   <= @P_BASECALC) AND (VRFIMFAIXA  >= @P_BASECALC) OR @V_UTFAIXVLR = 'N')
                  AND (ISNULL(IDORIGEMPRODIMP, 'N') =  ISNULL(@V_IDORIGEMPROD, 'N'));

               SELECT @V_IDMENSAGEM = (CASE COUNT(MSGFISCREGRA.CDREGRAFISC) WHEN 0 THEN 'N' ELSE 'S' END)
                 FROM MSGFISCREGRA
                WHERE CDREGRAFISC = @V_CDREGRAFISC
                  AND CDIMPOSTO = @V_REGRAFISCAL_CDIMPOSTO
                  AND NRSEQDADOSFISC = @V_NRSEQDADOSFISC;
            END;
         END;
      END;
      SELECT @V_NMREGRAFISC = NMREGRAFISC, @V_DSMENSREGRAFISC = DSMENSREGRAFISC
        FROM REGRAFISCAL
       WHERE CDREGRAFISC = @V_CDREGRAFISC;

      SET @V_CDFISCOPER     = ISNULL(@V_CDFISCOPER, @V_PCDFISCOPER);
      SET @V_IDCFOPINTEREST = ISNULL(@V_IDCFOPINTEREST, @V_PIDCFOPINTEREST);
      SET @V_IDDIFEALIQ     = ISNULL(@V_IDDIFEALIQ, @V_PIDDIFEALIQ);
      SET @V_IDDIFALIQCUSPR = ISNULL(@V_IDDIFALIQCUSPR, @V_PIDDIFALIQCUSPR);
      SET @V_IDTIPOREGISTRO = ISNULL(@V_IDTIPOREGISTRO, @V_PIDTIPOREGISTRO);
      SET @V_CDPRODUTO      = ISNULL(@V_CDPRODUTO, @V_PCDPRODUTO);
      SET @V_CDCLASFISC     = ISNULL(@V_CDCLASFISC, @V_PCDCLASFISC);
      SET @V_IDMENSAGEM     = ISNULL(@V_IDMENSAGEM, @V_PIDMENSAGEM);

      IF @V_CDREGRAFISC IS NOT NULL BEGIN
         IF @V_CDFISCAL        IS NOT NULL OR
            @V_CDSITUTRIB      IS NOT NULL OR
            @V_VRALIQUOTA      IS NOT NULL OR
            @V_IDMODBCNFE      IS NOT NULL OR
            @V_IDMODBCSTNFE    IS NOT NULL OR
            @V_IDMOTIDESSTNFE  IS NOT NULL OR
            @V_CDTPCRPICOSTNFE IS NOT NULL OR
            @V_CDNATUBCPCSTNFE IS NOT NULL OR
            @V_VRINIFAIXA      IS NOT NULL OR
            @V_VRFIMFAIXA      IS NOT NULL OR
            @V_VRPARDEDUZ      IS NOT NULL OR
            @V_VR1PERREDBC     IS NOT NULL OR
            @V_VRPERREDBC      IS NOT NULL OR
            @V_VRPBCSUBTRIB    IS NOT NULL OR
            @V_IDTRATIMPST     IS NOT NULL OR
            @V_IDPMCBASECA     IS NOT NULL OR
            @V_IDCSTINTEREST   IS NOT NULL OR
            @V_IDCSTINTERNA    IS NOT NULL OR
            @V_CDFISCOPER      IS NOT NULL OR
            @V_IDCFOPINTEREST  IS NOT NULL OR
            @V_IDDIFEALIQ      IS NOT NULL OR
            @V_IDDIFALIQCUSPR  IS NOT NULL OR
            @V_IDTIPODESTFISC  IS NOT NULL OR
            @V_CDDETALHEFISC   IS NOT NULL OR
            @V_IDTIPOREGISTRO  IS NOT NULL OR
            @V_NRSEQDADOSFISC  IS NOT NULL OR
            @V_IDMENSAGEM      IS NOT NULL OR
            @V_CDCLASFISC      IS NOT NULL OR
            @V_CDPRODUTO       IS NOT NULL OR
            @V_CDENQLEGALIPI   IS NOT NULL OR
            @V_CDCEST          IS NOT NULL OR
            @V_VRADICALIQFECP  IS NOT NULL BEGIN

            INSERT INTO @REGRAFISCAL_TABLE
            (CDREGRAFISC,          NMREGRAFISC,            DSMENSREGRAFISC,        CDIMPOSTO,
             CDFISCAL,             CDSITUTRIB,             VRALIQUOTA,             IDMODBCNFE,
             IDMODBCSTNFE,         IDMOTIDESSTNFE,         CDTPCRPICOSTNFE,        CDNATUBCPCSTNFE,
             VRINIFAIXA,           VRFIMFAIXA,             VRPARDEDUZ,             VR1PERREDBC,             VRPERREDBC,
             VRPBCSUBTRIB,         IDTRATIMPST,            IDPMCBASECA,            IDCSTINTEREST,           IDCSTINTERNA,
             CDFISCOPER,           IDCFOPINTEREST,         IDDIFEALIQ,             IDDIFALIQCUSPR,          IDTIPODESTFISC,
             CDDETALHEFISC,        IDTIPOREGISTRO,         NRSEQDADOSFISC,         IDMENSAGEM,              CDCLASFISC,
             CDPRODUTO,            CDENQLEGALIPI,          CDCEST,                 VRADICALIQFECP
             )
             VALUES
            (@V_CDREGRAFISC,          @V_NMREGRAFISC,            @V_DSMENSREGRAFISC,        @V_REGRAFISCAL_CDIMPOSTO,
             @V_CDFISCAL,             @V_CDSITUTRIB,             @V_VRALIQUOTA,             @V_IDMODBCNFE,
             @V_IDMODBCSTNFE,         @V_IDMOTIDESSTNFE,         @V_CDTPCRPICOSTNFE,        @V_CDNATUBCPCSTNFE,
             @V_VRINIFAIXA,           @V_VRFIMFAIXA,             @V_VRPARDEDUZ,             @V_VR1PERREDBC,             @V_VRPERREDBC,
             @V_VRPBCSUBTRIB,         @V_IDTRATIMPST,            @V_IDPMCBASECA,            @V_IDCSTINTEREST,           @V_IDCSTINTERNA,
             @V_CDFISCOPER,           @V_IDCFOPINTEREST,         @V_IDDIFEALIQ,             @V_IDDIFALIQCUSPR,          @V_IDTIPODESTFISC,
             @V_CDDETALHEFISC,        @V_IDTIPOREGISTRO,         @V_NRSEQDADOSFISC,         @V_IDMENSAGEM,              @V_CDCLASFISC,             
             @V_CDPRODUTO,            @V_CDENQLEGALIPI,          @V_CDCEST,                 @V_VRADICALIQFECP);
         END;
      END;
      FETCH NEXT FROM C_REGRAFISCAL INTO @V_REGRAFISCAL_CDIMPOSTO, @V_REGRAFISCAL_ORDEM;
   END;
   CLOSE C_REGRAFISCAL;
   DEALLOCATE C_REGRAFISCAL;
   RETURN;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'CONSULTA_REGRA_FISCAL','6.05.xxx';
GO
